// You can import API functions like this from D3.js.
import {
  select,
  max,
  csv,
  scaleBand,
  scaleLinear,
  axisLeft,
  axisBottom,
} from 'd3';

const svg = select('svg');

const width = +svg.attr('width');
const height = +svg.attr('height');
var margin = {
  left: 80,
  top: 10,
  bottom: 100,
  right: 10,
};

const x = scaleBand().range([
  margin.left,
  width - margin.right - margin.right,
]);
var xAx = svg
  .append('g')
  .attr(
    'transform',
    'translate(' + margin.left + ',0)'
  );

const y = scaleLinear().range([
  height - margin.bottom,
  margin.top,
]);
var yAx = svg
  .append('g')
  .attr(
    'transform',
    'translate(' + margin.left + ',0)'
  );

const update = (data) => {
  x.domain(data.map((d) => d.Country));
  xAx
    .call(d3.axisBottom(x))
    .attr('transform', 'translate(0, 410)')
    .selectAll('text')
    .style('text-anchor', 'end')
    .attr('dx', '-1em')
    .attr('dy', '-0.5em')
    .attr('transform', 'rotate(-60)');

  y.domain([
    0,
    max(data, (d) => +d['2022 Population']),
  ]);
  yAx.call(d3.axisLeft(y));

  svg
    .selectAll('rect')
    .data(data)
    .enter()
    .append('rect')
    .attr('x', (d) => x(d.Country))
    .attr('y', (d) => y(+d['2022 Population']))
    .attr('width', x.bandwidth())
    .attr(
      'height',
      (d) =>
        height -
        margin.bottom -
        y(d['2022 Population'])
    )
   .on('mouseover', function(d) {
        y(d['2022 Population'])
 d3.select('#tooltip').transition().duration(200).style('opacity', 1).text(d.Country + ' '+ d['2022 Population'])
 })
 .on('mouseout', function() {
 d3.select('#tooltip').style('opacity', 0)
 })
 .on('mousemove', function() {
 d3.select('#tooltip').style('left', (d3.event.pageX+10) + 'px').style('top', (d3.event.pageY+10) + 'px')
 });
};

d3.select('.btn0')
.on("click", function() {
    svg.selectAll("rect")
        .sort(function(a, b) {
                return d3.ascending(+a['2022 Population'], +b['2022 Population']); 
        })
        .transition()
        .duration(1000)
        .attr("x", function(d, i) { //对排序之后的横坐标重排
            return x(i);
        });
  /*
    svg.selectAll('rect')
        .sort(function(a, b) {
                return d3.ascending(+a['2022 Population'], +b['2022 Population']); 
        })
        .transition()
        .duration(1000)
        .attr("x", function(d, i) { //对排序之后的横坐标重排
            return x(i)+ x.bandwidth() / 2;
        });
        */
});


csv('data.csv').then((data) => {
  data.forEach((d) => {
    // console.log(d.Country,
    //             d['2022 